@@ -1,6 +1,6 @@
 #' @title Read the Content of a Markdown Table
 #'
-#' @details Performs basic parsing of a markdown table and passes it along to 
+#' @details Performs basic parsing of a markdown table and passes it along to
 #'   [readr::read_delim].
 #'
 #' @inheritParams read_md_table
@@ -11,11 +11,9 @@
 #' @keywords internal
 #'
 #' @noRd
-read_md_table_content <- function(markdown_table, warn = TRUE, ...) {
+read_md_table_content <- function(markdown_table, ...) {
   markdown_table <- stringr::str_split(markdown_table, "\n")[[1]]
 
-  if (warn) warn_md_table(markdown_table)
-
   # Remove the header separator line (second line)
   markdown_table <- markdown_table[-2]
 
